# Changelog

## 0.1.1 (2023-03-22)

#### Fixes

* strip trailing spaces from track titles.


## v0.1.0 (2023-03-22)

#### New Features

* add param to control overwriting existing files.
#### Others

* build v0.1.0
* update changelog
* update with added param


## v0.0.0 (2023-03-22)

#### Others

* build v0.0.0
* add keywords to pyproject